/* Tabela RECESERV: Receita por Servio  */
/* Descrição: A trigger insere registros na tabela LOGOPERA a partir de alterações na tabela RECESERV */
/* Objetivo: Gerar um log que vai registrar as alterações na tabela Receita por Servio,
             utilizando a tabela Geral de Logs de Operações */

IF EXISTS(SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'LOG_PLA_RECESERV'  and
            type = 'TR'               and
            u.uid = o.uid             and
            u.name = USER)
   DROP TRIGGER LOG_PLA_RECESERV
GO

CREATE TRIGGER LOG_PLA_RECESERV
ON RECESERV
AFTER DELETE, INSERT, UPDATE
AS
BEGIN

   DECLARE @V_USUARIO         VARCHAR(40);
   DECLARE @V_TIPO            VARCHAR(1);
   DECLARE @V_ITPESQ          VARCHAR(40);
   DECLARE @V_DESC            VARCHAR(500);
   DECLARE @V_DTOPER          DATETIME;

   DECLARE @V_DSREMOTEADDR     VARCHAR(15);
   DECLARE @V_DSREMOTEHOST     VARCHAR(15);
   DECLARE @V_DSSERVERRDM      VARCHAR(20);
   DECLARE @V_DSSERVMETHOD     VARCHAR(30);
   DECLARE @V_DSREMOTEOPER     VARCHAR(12);

   DECLARE @V_CDARVPROD VARCHAR(20);

   DECLARE @V_CDFILIAL VARCHAR(04);

/* Variáveis do cursor */

   DECLARE @V_IDCOMANDO         VARCHAR(01);
   DECLARE @V_OLD_CDPRATO       VARCHAR(10);
   DECLARE @V_OLD_CDFILAUXPRAT  VARCHAR(04);
   DECLARE @V_OLD_CDFILIAL      VARCHAR(04);
   DECLARE @V_OLD_CDSERVFILI    VARCHAR(05);
   DECLARE @V_OLD_CDPRODUTO     VARCHAR(10);
   DECLARE @V_OLD_QTPRODRECSER  DOUBLE PRECISION;
   DECLARE @V_OLD_CDAPRERECE    VARCHAR(10);
   DECLARE @V_OLD_SGUNIDADE     VARCHAR(05);
   DECLARE @V_OLD_HRTEMPPREPSE  VARCHAR(05);
   DECLARE @V_OLD_IDPRODBASESE  VARCHAR(01);
   DECLARE @V_OLD_VRPEFATCOCSE  DOUBLE PRECISION;
   DECLARE @V_OLD_VRPEFATCORSE  DOUBLE PRECISION;
   DECLARE @V_OLD_QTBRUTASEUNR  DOUBLE PRECISION;
   DECLARE @V_OLD_QTBRUTASE     DOUBLE PRECISION;
   DECLARE @V_OLD_VRPEFATNUTSE  DOUBLE PRECISION;
   DECLARE @V_OLD_QTCALCNUTRSE  DOUBLE PRECISION;

   DECLARE @V_NEW_CDPRATO       VARCHAR(10);
   DECLARE @V_NEW_CDFILAUXPRAT  VARCHAR(04);
   DECLARE @V_NEW_CDFILIAL      VARCHAR(04);
   DECLARE @V_NEW_CDSERVFILI    VARCHAR(05);
   DECLARE @V_NEW_CDPRODUTO     VARCHAR(10);
   DECLARE @V_NEW_QTPRODRECSER  DOUBLE PRECISION;
   DECLARE @V_NEW_CDAPRERECE    VARCHAR(10);
   DECLARE @V_NEW_SGUNIDADE     VARCHAR(05);
   DECLARE @V_NEW_HRTEMPPREPSE  VARCHAR(05);
   DECLARE @V_NEW_IDPRODBASESE  VARCHAR(01);
   DECLARE @V_NEW_VRPEFATCOCSE  DOUBLE PRECISION;
   DECLARE @V_NEW_VRPEFATCORSE  DOUBLE PRECISION;
   DECLARE @V_NEW_QTBRUTASEUNR  DOUBLE PRECISION;
   DECLARE @V_NEW_QTBRUTASE     DOUBLE PRECISION;
   DECLARE @V_NEW_VRPEFATNUTSE  DOUBLE PRECISION;
   DECLARE @V_NEW_QTCALCNUTRSE  DOUBLE PRECISION;

   SET @V_IDCOMANDO         = NULL;
   SET @V_OLD_CDPRATO       = NULL;
   SET @V_OLD_CDFILAUXPRAT  = NULL;
   SET @V_OLD_CDFILIAL      = NULL;
   SET @V_OLD_CDSERVFILI    = NULL;
   SET @V_OLD_CDPRODUTO     = NULL;
   SET @V_OLD_QTPRODRECSER  = NULL;
   SET @V_OLD_CDAPRERECE    = NULL;
   SET @V_OLD_SGUNIDADE     = NULL;
   SET @V_OLD_HRTEMPPREPSE  = NULL;
   SET @V_OLD_IDPRODBASESE  = NULL;
   SET @V_OLD_VRPEFATCOCSE  = NULL;
   SET @V_OLD_VRPEFATCORSE  = NULL;
   SET @V_OLD_QTBRUTASEUNR  = NULL;
   SET @V_OLD_QTBRUTASE     = NULL;
   SET @V_OLD_VRPEFATNUTSE  = NULL;
   SET @V_OLD_QTCALCNUTRSE  = NULL;
   SET @V_NEW_CDPRATO       = NULL;
   SET @V_NEW_CDFILAUXPRAT  = NULL;
   SET @V_NEW_CDFILIAL      = NULL;
   SET @V_NEW_CDSERVFILI    = NULL;
   SET @V_NEW_CDPRODUTO     = NULL;
   SET @V_NEW_QTPRODRECSER  = NULL;
   SET @V_NEW_CDAPRERECE    = NULL;
   SET @V_NEW_SGUNIDADE     = NULL;
   SET @V_NEW_HRTEMPPREPSE  = NULL;
   SET @V_NEW_IDPRODBASESE  = NULL;
   SET @V_NEW_VRPEFATCOCSE  = NULL;
   SET @V_NEW_VRPEFATCORSE  = NULL;
   SET @V_NEW_QTBRUTASEUNR  = NULL;
   SET @V_NEW_QTBRUTASE     = NULL;
   SET @V_NEW_VRPEFATNUTSE  = NULL;
   SET @V_NEW_QTCALCNUTRSE  = NULL;

   SET @V_TIPO = '0';
   SET @V_DESC = '';

   EXEC NMUSUARIO @V_USUARIO;
   EXEC WEBTUNNING @V_DSREMOTEADDR,
                   @V_DSREMOTEHOST,
                   @V_DSSERVERRDM,
                   @V_DSSERVMETHOD,
                   @V_DSREMOTEOPER;

   SET @V_USUARIO = ISNULL(@V_USUARIO, '');

   DECLARE C_DADOS CURSOR FOR
      SELECT
         'D' IDCOMANDO,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          CDPRATO,
          CDFILAUXPRAT,
          CDFILIAL,
          CDSERVFILI,
          CDPRODUTO,
          QTPRODRECSER,
          CDAPRERECE,
          SGUNIDADE,
          HRTEMPPREPSE,
          IDPRODBASESE,
          VRPEFATCOCSE,
          VRPEFATCORSE,
          QTBRUTASEUNR,
          QTBRUTASE,
          VRPEFATNUTSE,
          QTCALCNUTRSE
      FROM
         DELETED
      WHERE
         0 = (SELECT COUNT(*) FROM INSERTED)

      UNION ALL

      SELECT
         'U' IDCOMANDO,
          INSERTED.CDPRATO,
          INSERTED.CDFILAUXPRAT,
          INSERTED.CDFILIAL,
          INSERTED.CDSERVFILI,
          INSERTED.CDPRODUTO,
          INSERTED.QTPRODRECSER,
          INSERTED.CDAPRERECE,
          INSERTED.SGUNIDADE,
          INSERTED.HRTEMPPREPSE,
          INSERTED.IDPRODBASESE,
          INSERTED.VRPEFATCOCSE,
          INSERTED.VRPEFATCORSE,
          INSERTED.QTBRUTASEUNR,
          INSERTED.QTBRUTASE,
          INSERTED.VRPEFATNUTSE,
          INSERTED.QTCALCNUTRSE,

          DELETED.CDPRATO,
          DELETED.CDFILAUXPRAT,
          DELETED.CDFILIAL,
          DELETED.CDSERVFILI,
          DELETED.CDPRODUTO,
          DELETED.QTPRODRECSER,
          DELETED.CDAPRERECE,
          DELETED.SGUNIDADE,
          DELETED.HRTEMPPREPSE,
          DELETED.IDPRODBASESE,
          DELETED.VRPEFATCOCSE,
          DELETED.VRPEFATCORSE,
          DELETED.QTBRUTASEUNR,
          DELETED.QTBRUTASE,
          DELETED.VRPEFATNUTSE,
          DELETED.QTCALCNUTRSE
      FROM
         INSERTED,
         DELETED
      WHERE
         INSERTED.CDFILIAL     = DELETED.CDFILIAL     AND
         INSERTED.CDSERVFILI   = DELETED.CDSERVFILI   AND
         INSERTED.CDPRATO      = DELETED.CDPRATO      AND
         INSERTED.CDFILAUXPRAT = DELETED.CDFILAUXPRAT AND
         INSERTED.CDPRODUTO    = DELETED.CDPRODUTO

      UNION ALL

      SELECT
         'I' IDCOMANDO,
          CDPRATO,
          CDFILAUXPRAT,
          CDFILIAL,
          CDSERVFILI,
          CDPRODUTO,
          QTPRODRECSER,
          CDAPRERECE,
          SGUNIDADE,
          HRTEMPPREPSE,
          IDPRODBASESE,
          VRPEFATCOCSE,
          VRPEFATCORSE,
          QTBRUTASEUNR,
          QTBRUTASE,
          VRPEFATNUTSE,
          QTCALCNUTRSE,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL,
          NULL
      FROM
         INSERTED
      WHERE
         0 = (SELECT COUNT(*) FROM DELETED);

   OPEN C_DADOS;
   FETCH NEXT FROM C_DADOS INTO @V_IDCOMANDO,
                                @V_NEW_CDPRATO,
                                @V_NEW_CDFILAUXPRAT,
                                @V_NEW_CDFILIAL,
                                @V_NEW_CDSERVFILI,
                                @V_NEW_CDPRODUTO,
                                @V_NEW_QTPRODRECSER,
                                @V_NEW_CDAPRERECE,
                                @V_NEW_SGUNIDADE,
                                @V_NEW_HRTEMPPREPSE,
                                @V_NEW_IDPRODBASESE,
                                @V_NEW_VRPEFATCOCSE,
                                @V_NEW_VRPEFATCORSE,
                                @V_NEW_QTBRUTASEUNR,
                                @V_NEW_QTBRUTASE,
                                @V_NEW_VRPEFATNUTSE,
                                @V_NEW_QTCALCNUTRSE,
                                @V_OLD_CDPRATO,
                                @V_OLD_CDFILAUXPRAT,
                                @V_OLD_CDFILIAL,
                                @V_OLD_CDSERVFILI,
                                @V_OLD_CDPRODUTO,
                                @V_OLD_QTPRODRECSER,
                                @V_OLD_CDAPRERECE,
                                @V_OLD_SGUNIDADE,
                                @V_OLD_HRTEMPPREPSE,
                                @V_OLD_IDPRODBASESE,
                                @V_OLD_VRPEFATCOCSE,
                                @V_OLD_VRPEFATCORSE,
                                @V_OLD_QTBRUTASEUNR,
                                @V_OLD_QTBRUTASE,
                                @V_OLD_VRPEFATNUTSE,
                                @V_OLD_QTCALCNUTRSE

   WHILE (@@FETCH_STATUS = 0) BEGIN
      IF @V_IDCOMANDO = 'D' /* Deleting */ BEGIN

         SET @V_DESC = @V_DESC + 'Prato=' + @V_OLD_CDPRATO + ' - ' + @V_OLD_CDFILAUXPRAT;
         SET @V_DESC = @V_DESC + ' Fili=' + @V_OLD_CDFILIAL;
         SET @V_DESC = @V_DESC + ' Serv=' + @V_OLD_CDSERVFILI;

         SELECT @V_CDARVPROD = CDARVPROD
         FROM PRODUTO
         WHERE CDPRODUTO = @V_OLD_CDPRODUTO;

         SET @V_DESC = @V_DESC + ' Prod=' + @V_CDARVPROD;

         IF (ISNULL(@V_OLD_CDAPRERECE, '¿') <> '¿') BEGIN
            SET @V_DESC = @V_DESC + ' Apres=' + @V_OLD_CDAPRERECE;
         END;

         IF (ISNULL(@V_OLD_QTPRODRECSER, -1) <> -1) BEGIN
            SET @V_DESC = @V_DESC + ' Qtde=' + CONVERT(VARCHAR, @V_OLD_QTPRODRECSER);
         END;

         IF NOT (@V_OLD_SGUNIDADE IS NULL) BEGIN
            SET @V_DESC = @V_DESC + ' Un=' + CONVERT(VARCHAR, @V_OLD_SGUNIDADE);
         END;

         IF (ISNULL(@V_OLD_VRPEFATCOCSE, -1) <> -1) BEGIN
            SET @V_DESC = @V_DESC + ' GanhoCoc=' + CONVERT(VARCHAR, @V_OLD_VRPEFATCOCSE);
         END;

         IF (ISNULL(@V_OLD_VRPEFATCORSE, -1) <> -1) BEGIN
            SET @V_DESC = @V_DESC + ' PerdLimp=' + CONVERT(VARCHAR, @V_OLD_VRPEFATCORSE);
         END;

         IF (ISNULL(@V_OLD_HRTEMPPREPSE, '¿') <> '¿') BEGIN
            SET @V_DESC = @V_DESC + ' Temp=' + SUBSTRING(@V_OLD_HRTEMPPREPSE, 1, 2) + ':' + SUBSTRING(@V_OLD_HRTEMPPREPSE, 4, 2);
         END;

         IF (ISNULL(@V_OLD_QTBRUTASEUNR, -1) <> -1) BEGIN
             SET @V_DESC = @V_DESC + ' QtBruta=' + CONVERT(VARCHAR, @V_OLD_QTBRUTASEUNR);
         END;

         IF (ISNULL(@V_OLD_QTBRUTASE, -1) <> -1) BEGIN
            SET @V_DESC = @V_DESC + ' QtReq=' + CONVERT(VARCHAR, @V_OLD_QTBRUTASE);
         END;

         IF NOT (@V_OLD_IDPRODBASESE IS NULL) BEGIN
            SET @V_DESC = @V_DESC + ' PrBase=' + CONVERT(VARCHAR, @V_OLD_IDPRODBASESE);
         END;

         IF (ISNULL(@V_OLD_VRPEFATNUTSE, -1) <> -1) BEGIN
            SET @V_DESC = @V_DESC + ' AprovNutr=' + CONVERT(VARCHAR, @V_OLD_VRPEFATNUTSE);
         END;

         IF (ISNULL(@V_OLD_QTCALCNUTRSE, -1) <> -1) BEGIN
            SET @V_DESC = @V_DESC + ' QtNutr=' + CONVERT(VARCHAR, @V_OLD_QTCALCNUTRSE);
         END;

         SET @V_TIPO = '3';

         SET @V_ITPESQ = @V_OLD_CDPRATO+@V_OLD_CDFILAUXPRAT+@V_OLD_CDFILIAL+@V_OLD_CDSERVFILI+@V_CDARVPROD;

         SET @V_DTOPER =  GETDATE();
         SELECT
            @V_DSSERVERRDM  = DSSERVERRDM,
            @V_DSREMOTEADDR = DSREMOTEADDR,
            @V_DSREMOTEHOST = DSREMOTEHOST,
            @V_DSSERVMETHOD = DSSERVMETHOD,
            @V_DSREMOTEOPER = DSREMOTEOPER
           FROM
            SQLWEBTUNNING
           WHERE NRAUDSID = @@SPID;
           SELECT @V_USUARIO = MAX(NMOPERADOR)
           FROM OPERADOR
           WHERE  @V_DSREMOTEOPER = CDOPERADOR;

         INSERT INTO LOGOPERA
            (NMTABELA,   DTOPERACAO, NMRESPOPER, IDTIPOOPER, CDPESQITEM, DSOPERACAO,
             DSRDMUSUOPER, DSENDUSUOPER, DSNMUSUOPER, DSMETUSUOPER, CDORESPOPER, CDFILLOGOPER)
         VALUES
            ('RECESERV',  @V_DTOPER, @V_USUARIO, @V_TIPO,  @V_ITPESQ, @V_DESC,
             @V_DSSERVERRDM, @V_DSREMOTEADDR,  @V_DSREMOTEHOST, @V_DSSERVMETHOD, @V_DSREMOTEOPER, @V_OLD_CDFILIAL);

      END;
      ELSE BEGIN
         IF @V_IDCOMANDO = 'U' /* Updating */ BEGIN

            IF (@V_OLD_CDPRATO      <> @V_NEW_CDPRATO     ) OR
               (@V_OLD_CDFILAUXPRAT <> @V_NEW_CDFILAUXPRAT) OR
               (@V_OLD_CDFILIAL     <> @V_NEW_CDFILIAL    ) OR
               (@V_OLD_CDSERVFILI   <> @V_NEW_CDSERVFILI) OR
               (@V_OLD_CDPRODUTO    <> @V_NEW_CDPRODUTO   ) OR
               (@V_OLD_QTPRODRECSER <> @V_NEW_QTPRODRECSER) OR
               (ISNULL(@V_OLD_CDAPRERECE,   '¿') <> ISNULL(@V_NEW_CDAPRERECE,   '¿')) OR
               (ISNULL(@V_OLD_SGUNIDADE,    '¿') <> ISNULL(@V_NEW_SGUNIDADE,    '¿')) OR
               (ISNULL(@V_OLD_HRTEMPPREPSE, '¿') <> ISNULL(@V_NEW_HRTEMPPREPSE, '¿')) OR
               (ISNULL(@V_OLD_IDPRODBASESE, '¿') <> ISNULL(@V_NEW_IDPRODBASESE, '¿')) OR
               (ISNULL(@V_OLD_VRPEFATCOCSE,  -1) <> ISNULL(@V_NEW_VRPEFATCOCSE,  -1)) OR
               (ISNULL(@V_OLD_VRPEFATCORSE,  -1) <> ISNULL(@V_NEW_VRPEFATCORSE,  -1)) OR
               (ISNULL(@V_OLD_QTBRUTASEUNR,  -1) <> ISNULL(@V_NEW_QTBRUTASEUNR,  -1)) OR
               (ISNULL(@V_OLD_QTBRUTASE,     -1) <> ISNULL(@V_NEW_QTBRUTASE,     -1)) OR
               (ISNULL(@V_OLD_VRPEFATNUTSE,  -1) <> ISNULL(@V_NEW_VRPEFATNUTSE,  -1)) OR
               (ISNULL(@V_OLD_QTCALCNUTRSE,  -1) <> ISNULL(@V_NEW_QTCALCNUTRSE,  -1)) BEGIN

               SELECT @V_CDARVPROD = CDARVPROD
               FROM PRODUTO
               WHERE CDPRODUTO = @V_OLD_CDPRODUTO;

               SET @V_TIPO  = '2';
               SET @V_ITPESQ = @V_OLD_CDPRATO+@V_OLD_CDFILAUXPRAT+@V_OLD_CDFILIAL+@V_OLD_CDSERVFILI+@V_CDARVPROD;
               SET @V_CDFILIAL = @V_OLD_CDFILIAL;
            END;
         END;
         ELSE BEGIN
            SELECT @V_CDARVPROD = CDARVPROD
            FROM PRODUTO
            WHERE CDPRODUTO = @V_NEW_CDPRODUTO;

            SET @V_TIPO   = '1';
            SET @V_ITPESQ = @V_NEW_CDPRATO+@V_NEW_CDFILAUXPRAT+@V_NEW_CDFILIAL+@V_NEW_CDSERVFILI+@V_CDARVPROD;
            SET @V_CDFILIAL = @V_NEW_CDFILIAL;
         END;
      END;

      IF (@V_OLD_CDPRATO <> @V_NEW_CDPRATO) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + 'Prato=' + @V_OLD_CDPRATO + '|' + @V_NEW_CDPRATO + ' - ';
         END;
         ELSE BEGIN
            SET @V_DESC = @V_DESC + 'Prato=' + @V_NEW_CDPRATO + ' - ';
         END;
      END;

      IF (@V_OLD_CDFILAUXPRAT <> @V_NEW_CDFILAUXPRAT) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + '-' + + @V_OLD_CDFILAUXPRAT + '|' + @V_NEW_CDFILAUXPRAT;
         END;
         ELSE BEGIN
            SET @V_DESC = @V_DESC + '-' + @V_NEW_CDFILAUXPRAT;
         END;
      END;

      IF (@V_OLD_CDFILIAL <> @V_NEW_CDFILIAL) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + 'Fili=' + @V_OLD_CDFILIAL + '|' + @V_NEW_CDFILIAL + ' - ';
         END;
         ELSE BEGIN
            SET @V_DESC = @V_DESC + 'Fili=' + @V_NEW_CDFILIAL + ' - ';
         END;
      END;

      IF (@V_OLD_CDSERVFILI <> @V_NEW_CDSERVFILI) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + 'Serv=' + @V_OLD_CDSERVFILI + '|' + @V_NEW_CDSERVFILI + ' - ';
         END;
         ELSE BEGIN
            SET @V_DESC = @V_DESC + 'Serv=' + @V_NEW_CDSERVFILI + ' - ';
         END;
      END;

      IF (@V_OLD_CDPRODUTO <> @V_NEW_CDPRODUTO) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SELECT @V_CDARVPROD = CDARVPROD
            FROM PRODUTO
            WHERE CDPRODUTO = @V_OLD_CDPRODUTO;
            SET @V_DESC = @V_DESC + ' Prod=' + @V_CDARVPROD;

            SELECT @V_CDARVPROD = CDARVPROD
            FROM PRODUTO
            WHERE CDPRODUTO = @V_NEW_CDPRODUTO;
            SET @V_DESC = @V_DESC + '|' + @V_CDARVPROD;
         END;
         ELSE BEGIN
            SELECT @V_CDARVPROD = CDARVPROD
            FROM PRODUTO
            WHERE CDPRODUTO = @V_NEW_CDPRODUTO;
            SET @V_DESC = @V_DESC + ' Prod=' + @V_CDARVPROD;
         END;
      END;

      IF (ISNULL(@V_OLD_CDAPRERECE, '¿') <> ISNULL(@V_NEW_CDAPRERECE, '¿')) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + ' Apres=' + @V_OLD_CDAPRERECE + '|' + @V_NEW_CDAPRERECE;
         END;
         ELSE BEGIN
            SET @V_DESC = @V_DESC + ' Apres=' + @V_NEW_CDAPRERECE;
         END;
      END;

      IF (ISNULL(@V_OLD_QTPRODRECSER, -1) <> ISNULL(@V_NEW_QTPRODRECSER, -1)) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + ' Qtde.=' + CONVERT(VARCHAR, @V_OLD_QTPRODRECSER) + '|' + CONVERT(VARCHAR, @V_NEW_QTPRODRECSER);
         END;
         ELSE BEGIN
            SET @V_DESC = @V_DESC + ' Qtde=' + CONVERT(VARCHAR, @V_NEW_QTPRODRECSER);
         END;
      END;

      IF (ISNULL(@V_OLD_SGUNIDADE, '¿') <> ISNULL(@V_NEW_SGUNIDADE, '¿')) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + ' Un=' + @V_OLD_SGUNIDADE + '|' + @V_NEW_SGUNIDADE;
         END;
         ELSE BEGIN
            SET @V_DESC = @V_DESC + ' Un=' + @V_NEW_SGUNIDADE;
         END;
      END;

      IF (ISNULL(@V_NEW_VRPEFATCOCSE, -1) <> ISNULL(@V_NEW_VRPEFATCOCSE, -1)) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + ' GanhoCoc=' + CONVERT(VARCHAR, @V_OLD_VRPEFATCOCSE) + '|' + CONVERT(VARCHAR, @V_NEW_VRPEFATCOCSE);
         END;
         ELSE BEGIN
            SET @V_DESC = @V_DESC + ' GanhoCoc=' + CONVERT(VARCHAR, @V_NEW_VRPEFATCOCSE);
         END;
      END;

      IF (ISNULL(@V_OLD_VRPEFATCORSE, -1) <> ISNULL(@V_NEW_VRPEFATCORSE, -1)) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + ' PerdLimp=' + CONVERT(VARCHAR, @V_OLD_VRPEFATCORSE) + '|' + CONVERT(VARCHAR, @V_NEW_VRPEFATCORSE);
         END;
         ELSE BEGIN
            SET @V_DESC = @V_DESC + ' PerdLimp=' + CONVERT(VARCHAR, @V_NEW_VRPEFATCORSE);
         END;
      END;

      IF (ISNULL(@V_OLD_HRTEMPPREPSE, '¿') <> ISNULL(@V_NEW_HRTEMPPREPSE, '¿')) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + ' Temp=' + SUBSTRING(@V_OLD_HRTEMPPREPSE, 1, 2) + ':' + SUBSTRING(@V_OLD_HRTEMPPREPSE, 4, 2) + '|' + SUBSTRING(@V_NEW_HRTEMPPREPSE, 1, 2) + ':' + SUBSTRING(@V_NEW_HRTEMPPREPSE, 4, 2);
         END
         ELSE BEGIN
            SET @V_DESC = @V_DESC + ' Temp=' + SUBSTRING(@V_NEW_HRTEMPPREPSE, 1, 2) + ':' + SUBSTRING(@V_NEW_HRTEMPPREPSE, 4, 2);
         END
      END;

      IF (ISNULL(@V_OLD_QTBRUTASEUNR, -1) <> ISNULL(@V_NEW_QTBRUTASEUNR, -1)) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + ' QtBruta=' + CONVERT(VARCHAR, @V_OLD_QTBRUTASEUNR) + '|' + CONVERT(VARCHAR, @V_NEW_QTBRUTASEUNR);
         END;
         ELSE BEGIN
            SET @V_DESC = @V_DESC + ' QtBruta=' + CONVERT(VARCHAR, @V_NEW_QTBRUTASEUNR);
         END;
      END;

      IF (ISNULL(@V_OLD_QTBRUTASE, -1) <> ISNULL(@V_NEW_QTBRUTASE, -1)) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + ' QtReq=' + CONVERT(VARCHAR, @V_OLD_QTBRUTASE) + '|' + CONVERT(VARCHAR, @V_NEW_QTBRUTASE);
         END;
         ELSE BEGIN
            SET @V_DESC = @V_DESC + ' QtReq=' + CONVERT(VARCHAR, @V_NEW_QTBRUTASE);
         END;
      END;

      IF (ISNULL(@V_OLD_IDPRODBASESE, '¿') <>ISNULL(@V_NEW_IDPRODBASESE, '¿')) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + ' PrBase=' + @V_OLD_IDPRODBASESE + '|' + @V_NEW_IDPRODBASESE;
         END;
         ELSE BEGIN
            SET @V_DESC = @V_DESC + ' PrBase=' + @V_NEW_IDPRODBASESE;
         END;
      END;

      IF (ISNULL(@V_OLD_VRPEFATNUTSE, -1) <> ISNULL(@V_NEW_VRPEFATNUTSE, -1)) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + ' AprovNutr=' + CONVERT(VARCHAR, @V_OLD_VRPEFATNUTSE) + '|' + CONVERT(VARCHAR, @V_NEW_VRPEFATNUTSE);
         END;
         ELSE BEGIN
            SET @V_DESC = @V_DESC + ' AprovNutr=' + CONVERT(VARCHAR, @V_NEW_VRPEFATNUTSE);
         END;
      END;

      IF (ISNULL(@V_OLD_QTCALCNUTRSE, -1) <> ISNULL(@V_NEW_QTCALCNUTRSE, -1)) BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC = @V_DESC + ' QtNutr=' + CONVERT(VARCHAR, @V_OLD_QTCALCNUTRSE) + '|' + CONVERT(VARCHAR, @V_NEW_QTCALCNUTRSE);
         END;
         ELSE BEGIN
            SET @V_DESC = @V_DESC + ' QtNutr=' + CONVERT(VARCHAR, @V_NEW_QTCALCNUTRSE);
         END;
      END;

      IF ((@V_TIPO = '1') OR (@V_TIPO = '2'))BEGIN
         IF NOT @V_DESC IS NULL BEGIN
            SET @V_USUARIO = '  ';
            IF NOT @V_USUARIO IS NULL BEGIN
               SET @V_DTOPER =  GETDATE();
  	            SELECT
                  @V_DSSERVERRDM  = DSSERVERRDM,
                  @V_DSREMOTEADDR = DSREMOTEADDR,
                  @V_DSREMOTEHOST = DSREMOTEHOST,
		            @V_DSSERVMETHOD = DSSERVMETHOD,
                  @V_DSREMOTEOPER = DSREMOTEOPER
   	           FROM
                  SQLWEBTUNNING
                 WHERE NRAUDSID = @@SPID;
                 SELECT @V_USUARIO = MAX(NMOPERADOR)
                 FROM OPERADOR
                 WHERE  @V_DSREMOTEOPER = CDOPERADOR;

               INSERT INTO LOGOPERA
                  (NMTABELA,   DTOPERACAO, NMRESPOPER, IDTIPOOPER, CDPESQITEM, DSOPERACAO,
                   DSRDMUSUOPER, DSENDUSUOPER, DSNMUSUOPER, DSMETUSUOPER, CDORESPOPER, CDFILLOGOPER)
               VALUES
                  ('RECESERV',  @V_DTOPER, @V_USUARIO, @V_TIPO,  @V_ITPESQ, @V_DESC,
                   @V_DSSERVERRDM, @V_DSREMOTEADDR,  @V_DSREMOTEHOST, @V_DSSERVMETHOD, @V_DSREMOTEOPER, @V_CDFILIAL);
            END;
         END;
      END;

      FETCH NEXT FROM C_DADOS INTO @V_IDCOMANDO,
                                @V_NEW_CDPRATO,
                                @V_NEW_CDFILAUXPRAT,
                                @V_NEW_CDFILIAL,
                                @V_NEW_CDSERVFILI,
                                @V_NEW_CDPRODUTO,
                                @V_NEW_QTPRODRECSER,
                                @V_NEW_CDAPRERECE,
                                @V_NEW_SGUNIDADE,
                                @V_NEW_HRTEMPPREPSE,
                                @V_NEW_IDPRODBASESE,
                                @V_NEW_VRPEFATCOCSE,
                                @V_NEW_VRPEFATCORSE,
                                @V_NEW_QTBRUTASEUNR,
                                @V_NEW_QTBRUTASE,
                                @V_NEW_VRPEFATNUTSE,
                                @V_NEW_QTCALCNUTRSE,
                                @V_OLD_CDPRATO,
                                @V_OLD_CDFILAUXPRAT,
                                @V_OLD_CDFILIAL,
                                @V_OLD_CDSERVFILI,
                                @V_OLD_CDPRODUTO,
                                @V_OLD_QTPRODRECSER,
                                @V_OLD_CDAPRERECE,
                                @V_OLD_SGUNIDADE,
                                @V_OLD_HRTEMPPREPSE,
                                @V_OLD_IDPRODBASESE,
                                @V_OLD_VRPEFATCOCSE,
                                @V_OLD_VRPEFATCORSE,
                                @V_OLD_QTBRUTASEUNR,
                                @V_OLD_QTBRUTASE,
                                @V_OLD_VRPEFATNUTSE,
                                @V_OLD_QTCALCNUTRSE
   END;
   CLOSE      C_DADOS;
   DEALLOCATE C_DADOS;

END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_PLA_RECESERV','5.85.000';
GO

